@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Apply melodic inversion to a series of notes
 
-our $VERSION = '0.0105';
+our $VERSION = '0.0106';
 
 use Data::Dumper::Compact qw(ddc);
 use List::SomeUtils qw(first_index);
@@ -117,7 +117,7 @@ Music::MelodicDevice::Inversion - Apply melodic inversion to a series of notes
 
 =head1 VERSION
 
-version 0.0105
+version 0.0106
 
 =head1 SYNOPSIS
 
@@ -192,7 +192,7 @@ Return the inverted series of notes.
 
 =head1 SEE ALSO
 
-The F<t/01-methods.t> and F<eg/> distribution programs
+The F<t/01-methods.t> and F<eg/*> distribution programs
 
 L<Music::AtonalUtil> (contains a similar "invert" method)
 
